@@ -101,3 +101,10 @@ latex_documents = [
 # during an actual deployment and won't cause any issue during usage.
 autodoc_mock_imports = ['glance_store.common.fs_mount',
                         'glance_store.common.cinder_utils']
+
+# Since version 4.2.0, Sphinx emits a warning when encountering a mocked
+# object, leading to the following error:
+#   "A mocked object is detected: 'glance_store.common.cinder_utils'"
+# To prevent this, we disable all warnings from the autodoc extension, since
+# there is no finer grain yet.
+suppress_warnings = ['autodoc.*']
