@@ -382,7 +382,7 @@ Related options:
     cfg.BoolOpt('cinder_use_multipath',
                 default=False,
                 help="""
-Flag to identify mutipath is supported or not in the deployment.
+Flag to identify multipath is supported or not in the deployment.
 
 Set it to False if multipath is not supported.
 
@@ -532,7 +532,7 @@ class Store(glance_store.driver.Store):
                     return True
         except Exception:
             # Glance calls this method to update legacy images URL
-            # If an exception occours due to image/volume is non-existent or
+            # If an exception occurs due to image/volume is non-existent or
             # any other reason, we return False (i.e. the image location URL
             # won't be updated) and it is glance's responsibility to handle
             # the case when the image failed to update
@@ -641,6 +641,37 @@ class Store(glance_store.driver.Store):
             raise exceptions.BadStoreConfiguration(store_name="cinder",
                                                    reason=reason)
 
+    @staticmethod
+    def _get_device_size(device_file):
+        # The seek position is corrected after every extend operation
+        # with the bytes written (which is after this wait call) so we
+        # don't need to worry about setting it back to original position
+        device_file.seek(0, os.SEEK_END)
+        # There are other ways to determine the file size like os.stat
+        # or os.path.getsize but it requires file name attribute which
+        # we don't have for the RBD file wrapper RBDVolumeIOWrapper
+        device_size = device_file.tell()
+        device_size = int(math.ceil(float(device_size) / units.Gi))
+        return device_size
+
+    @staticmethod
+    def _wait_resize_device(volume, device_file):
+        timeout = 20
+        max_recheck_wait = 10
+        tries = 0
+        elapsed = 0
+        while Store._get_device_size(device_file) < volume.size:
+            wait = min(0.5 * 2 ** tries, max_recheck_wait)
+            time.sleep(wait)
+            tries += 1
+            elapsed += wait
+            if elapsed >= timeout:
+                msg = (_('Timeout while waiting while volume %(volume_id)s '
+                         'to resize the device in %(tries)s tries.')
+                       % {'volume_id': volume.id, 'tries': tries})
+                LOG.error(msg)
+                raise exceptions.BackendException(msg)
+
     def _wait_volume_status(self, volume, status_transition, status_expected):
         max_recheck_wait = 15
         timeout = self.store_conf.cinder_state_transition_timeout
@@ -685,6 +716,12 @@ class Store(glance_store.driver.Store):
         """
         return os.path.join(mount_point_base, self.get_hash_str(share))
 
+    def _get_host_ip(self, host):
+        try:
+            return socket.getaddrinfo(host, None, socket.AF_INET6)[0][4][0]
+        except socket.gaierror:
+            return socket.getaddrinfo(host, None, socket.AF_INET)[0][4][0]
+
     @contextlib.contextmanager
     def _open_cinder_volume(self, client, volume, mode):
         attach_mode = 'rw' if mode == 'wb' else 'ro'
@@ -692,13 +729,14 @@ class Store(glance_store.driver.Store):
         root_helper = self.get_root_helper()
         priv_context.init(root_helper=shlex.split(root_helper))
         host = socket.gethostname()
+        my_ip = self._get_host_ip(host)
         use_multipath = self.store_conf.cinder_use_multipath
         enforce_multipath = self.store_conf.cinder_enforce_multipath
         mount_point_base = self.store_conf.cinder_mount_point_base
         volume_id = volume.id
 
         connector_prop = connector.get_connector_properties(
-            root_helper, host, use_multipath, enforce_multipath)
+            root_helper, my_ip, use_multipath, enforce_multipath, host=host)
 
         if volume.multiattach:
             attachment = attachment_state_manager.attach(client, volume_id,
@@ -710,7 +748,6 @@ class Store(glance_store.driver.Store):
         attachment = self.volume_api.attachment_update(
             client, attachment['id'], connector_prop,
             mountpoint='glance_store')
-        self.volume_api.attachment_complete(client, attachment.id)
         volume = volume.manager.get(volume_id)
         connection_info = attachment.connection_info
 
@@ -751,6 +788,10 @@ class Store(glance_store.driver.Store):
                 device = connect_volume_nfs()
             else:
                 device = conn.connect_volume(connection_info)
+
+            # Complete the attachment (marking the volume "in-use") after
+            # the connection with os-brick is complete
+            self.volume_api.attachment_complete(client, attachment.id)
             if (connection_info['driver_volume_type'] == 'rbd' and
                not conn.do_local_attach):
                 yield device['path']
@@ -942,6 +983,10 @@ class Store(glance_store.driver.Store):
         try:
             while need_extend:
                 with self._open_cinder_volume(client, volume, 'wb') as f:
+                    # Sometimes the extended LUN on storage side takes time
+                    # to reflect in the device so we wait until the device
+                    # size is equal to the extended volume size.
+                    Store._wait_resize_device(volume, f)
                     f.seek(bytes_written)
                     if buf:
                         f.write(buf)
