@@ -158,7 +158,7 @@ Enable or not thin provisioning in this backend.
 This configuration option enable the feature of not really write null byte
 sequences on the RBD backend, the holes who can appear will automatically
 be interpreted by Ceph as null bytes, and do not really consume your storage.
-Enabling this feature will also speed up image upload and save network trafic
+Enabling this feature will also speed up image upload and save network traffic
 in addition to save space in the backend, as null bytes sequences are not
 sent over the network.
 
@@ -434,6 +434,14 @@ class Store(driver.Store):
             'snapshot': DEFAULT_SNAPNAME,
         }, self.conf)
 
+    def _snapshot_has_external_reference(self, image, snapshot_name):
+        """Returns True if snapshot has external reference else False.
+        """
+        image.set_snap(snapshot_name)
+        has_references = bool(image.list_children())
+        image.set_snap(None)
+        return has_references
+
     def _delete_image(self, target_pool, image_name,
                       snapshot_name=None, context=None):
         """
@@ -453,6 +461,14 @@ class Store(driver.Store):
                     if snapshot_name is not None:
                         with rbd.Image(ioctx, image_name) as image:
                             try:
+                                # NOTE(abhishekk): Check whether snapshot
+                                # has any external references
+                                if self._snapshot_has_external_reference(
+                                        image, snapshot_name):
+                                    raise rbd.ImageBusy(
+                                        "Image snapshot has external "
+                                        "references.")
+
                                 self._unprotect_snapshot(image, snapshot_name)
                                 image.remove_snap(snapshot_name)
                             except rbd.ImageNotFound as exc:
@@ -544,7 +560,7 @@ class Store(driver.Store):
                 # Fix with encodeutils.safe_decode CAN BE REMOVED
                 # after librados's fix will be stable.
                 #
-                # More informations:
+                # More information:
                 # https://bugs.launchpad.net/glance-store/+bug/1816721
                 # https://bugs.launchpad.net/cinder/+bug/1816468
                 # https://tracker.ceph.com/issues/38381
