@@ -83,9 +83,15 @@ class SwiftConnectionManager(object):
             auth_ref = self.client.session.auth.auth_ref
             # if connection token is going to expire soon (keystone checks
             # is token is going to expire or expired already)
-            if auth_ref.will_expire_soon(
-                self.store.conf.glance_store.swift_store_expire_soon_interval
-            ):
+            if self.store.backend_group:
+                interval = getattr(
+                    self.store.conf, self.store.backend_group
+                ).swift_store_expire_soon_interval
+            else:
+                store_conf = self.store.conf.glance_store
+                interval = store_conf.swift_store_expire_soon_interval
+
+            if auth_ref.will_expire_soon(interval):
                 LOG.info(_LI("Requesting new token for swift connection."))
                 # request new token with session and client provided by store
                 auth_token = self.client.session.get_auth_headers().get(
@@ -137,11 +143,16 @@ class SingleTenantConnectionManager(SwiftConnectionManager):
     def _get_storage_url(self):
         """Get swift endpoint from keystone
 
-        Return endpoint for swift from service catalog. The method works only
-        Keystone v3. If you are using different version (1 or 2)
+        Return endpoint for swift from service catalog if not overridden in
+        store configuration. The method works only Keystone v3.
+        If you are using different version (1 or 2)
         it returns None.
         :return: swift endpoint
         """
+
+        if self.store.conf_endpoint:
+            return self.store.conf_endpoint
+
         if self.store.auth_version == '3':
             try:
                 return self.client.session.get_endpoint(
