@@ -57,9 +57,9 @@ Possible values:
         * http
         * swift
         * rbd
-        * sheepdog
         * cinder
         * vmware
+        * s3
 
 Related Options:
     * default_store
@@ -69,7 +69,7 @@ Related Options:
                default='file',
                choices=('file', 'filesystem', 'http', 'https', 'swift',
                         'swift+http', 'swift+https', 'swift+config', 'rbd',
-                        'sheepdog', 'cinder', 'vsphere'),
+                        'cinder', 'vsphere', 's3'),
                deprecated_for_removal=True,
                deprecated_since='Rocky',
                deprecated_reason="""
@@ -101,9 +101,9 @@ Possible values:
     * swift+https
     * swift+config
     * rbd
-    * sheepdog
     * cinder
     * vsphere
+    * s3
 
 Related Options:
     * stores
