@@ -16,9 +16,10 @@
 """Tests the VMware Datastore backend store"""
 
 import hashlib
+from unittest import mock
 import uuid
 
-import mock
+from oslo_utils import secretutils
 from oslo_utils import units
 from oslo_vmware import api
 from oslo_vmware import exceptions as vmware_exceptions
@@ -145,7 +146,7 @@ class TestStore(base.StoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_size = FIVE_KB
         expected_contents = b"*" * expected_size
-        hash_code = hashlib.md5(expected_contents)
+        hash_code = secretutils.md5(expected_contents, usedforsecurity=False)
         expected_checksum = hash_code.hexdigest()
         sha256_code = hashlib.sha256(expected_contents)
         expected_multihash = sha256_code.hexdigest()
@@ -190,7 +191,7 @@ class TestStore(base.StoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_size = FIVE_KB
         expected_contents = b"*" * expected_size
-        hash_code = hashlib.md5(expected_contents)
+        hash_code = secretutils.md5(expected_contents, usedforsecurity=False)
         expected_checksum = hash_code.hexdigest()
         sha256_code = hashlib.sha256(expected_contents)
         expected_multihash = sha256_code.hexdigest()
@@ -303,7 +304,8 @@ class TestStore(base.StoreBaseTest,
     def test_reader_full(self):
         content = b'XXX'
         image = six.BytesIO(content)
-        expected_checksum = hashlib.md5(content).hexdigest()
+        expected_checksum = secretutils.md5(content,
+                                            usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(content).hexdigest()
         reader = vm_store._Reader(image, self.hash_algo)
         ret = reader.read()
@@ -315,7 +317,8 @@ class TestStore(base.StoreBaseTest,
     def test_reader_partial(self):
         content = b'XXX'
         image = six.BytesIO(content)
-        expected_checksum = hashlib.md5(b'X').hexdigest()
+        expected_checksum = secretutils.md5(b'X',
+                                            usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(b'X').hexdigest()
         reader = vm_store._Reader(image, self.hash_algo)
         ret = reader.read(1)
